@@ -84,6 +84,7 @@ nlminbControl <- function(eval.max=200,
                           rxControl=NULL,
                           optExpression=TRUE, sumProd=FALSE,
                           literalFix=TRUE,
+                          literalFixRes=TRUE,
                           returnNlminb=FALSE,
                           solveType=c("hessian", "grad", "fun"),
 
@@ -124,6 +125,8 @@ nlminbControl <- function(eval.max=200,
   checkmate::assertNumeric(step.max, len=1, any.missing=FALSE, lower=0)
   checkmate::assertLogical(optExpression, len=1, any.missing=FALSE)
   checkmate::assertLogical(literalFix, len=1, any.missing=FALSE)
+  checkmate::assertLogical(literalFixRes, len=1, any.missing=FALSE)
+
   checkmate::assertLogical(sumProd, len=1, any.missing=FALSE)
   checkmate::assertLogical(returnNlminb, len=1, any.missing=FALSE)
   checkmate::assertLogical(calcTables, len=1, any.missing=FALSE)
@@ -275,6 +278,7 @@ nlminbControl <- function(eval.max=200,
                covMethod=covMethod,
                optExpression=optExpression,
                literalFix=literalFix,
+               literalFixRes=literalFixRes,
                sumProd=sumProd,
                rxControl=rxControl,
                returnNlminb=returnNlminb,
@@ -479,6 +483,7 @@ getValidNlmixrCtl.nlminb <- function(control) {
                                 sumProd=.nlminbControl$sumProd,
                                 optExpression=.nlminbControl$optExpression,
                                 literalFix=.nlminbControl$literalFix,
+                                literalFixRes=.nlminbControl$literalFixRes,
                                 scaleTo=0,
                                 calcTables=.nlminbControl$calcTables,
                                 addProp=.nlminbControl$addProp,
