@@ -3,14 +3,7 @@
 #include <boost/algorithm/string.hpp>
 #include <string>
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("rxode2", String)
-/* replace pkg as appropriate */
-#else
 #define _(String) (String)
-#endif
-
 
 void calculateDfFull(arma::Col<int>& ID, arma::mat &etas,
                      List &etasDfFull, int &nid, unsigned int &neta) {
@@ -114,6 +107,10 @@ static inline SEXP dfProtectedNames(SEXP inS, std::string what) {
     UNPROTECT(1);
     return R_NilValue;
   }
+  if (TYPEOF(nmS) != STRSXP) {
+    UNPROTECT(1);
+    return R_NilValue;
+  }
   CharacterVector nm = as<CharacterVector>(nmS);
   const char *badNames[28] = {"IPRED", "IRES", "IWRES", "CENS", "LIMIT",
     "lowerLim", "upperLim","PRED", "RES", "CPRED",
